# Generated by Django 2.0.2 on 2018-02-09 11:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('wxmgmt', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tenant',
            name='kefuxinxi',
        ),
    ]
