# Generated by Django 2.0.2 on 2018-02-10 08:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wxmgmt', '0002_remove_tenant_kefuxinxi'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tenant',
            name='_jsapi_ticket',
            field=models.CharField(blank=True, default='', max_length=200),
        ),
        migrations.AlterField(
            model_name='tenant',
            name='shanghu_id',
            field=models.CharField(blank=True, default='', help_text='微信支付商户号', max_length=50),
        ),
    ]
